@@ -16,7 +16,8 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with sawfish; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301 USA.
 
 ;; Commentary:
 
@@ -447,7 +448,7 @@
   (define-match-window-setter 'dimensions
     (lambda (w prop value)
       (declare (unused prop))
-      (resize-window-with-hints w (car value) (cdr value))))
+      (resize-window-with-hints* w (car value) (cdr value))))
 
   (define-match-window-setter 'viewport
     (lambda (w prop value)
